local M = {}

local function createFile (path, key, value)
	local arr = {}
	arr[key] = value
	jsonWriteFile(path, arr, true)
end

local function create_or_remove (action)
	print("Work.")

	local prefix = "_customizableVGTOL"
	local allJbeamFile = FS:findFiles("vehicles/", "*.jbeam", -1, true, true)
	local filejbeam
	
	for i,jbeamPath in pairs(allJbeamFile) do
		if jbeamPath:sub(#jbeamPath-#prefix-5) == prefix..".jbeam" then
			os.remove(jbeamPath)
			goto continue
		end
		if action == "remove" then goto continue end

		filejbeam = jsonReadFile(jbeamPath)
		if filejbeam then
			for part,data in pairs(filejbeam) do
				part = part:gsub(' ',"_")
				if data and (data.pressureWheels or data.hubWheels) then
					local pressureOrHub
					if data.pressureWheels then
						pressureOrHub = "pressureWheels"
					else
						pressureOrHub = "hubWheels"
					end

					for _,Table in pairs(data[pressureOrHub]) do
						if Table.tireWidth then
							if data.information then
								if data.information.authors then
									data.information.authors = data.information.authors.."/_N_S_"
								end

								if data.information.name then
									data.information.name = data.information.name.." Customizable"
								end
							end

							local FrictionDefault = 1.0
							local SlidingFrictionDefault = 1.0
							local Max = 10
							local Min = 1 / Max

							local frictionCoefFound = false
							local slidingFrictionCoefFound = false

							for _,T in pairs(data[pressureOrHub]) do
								if T.frictionCoef then
									if tonumber(T.frictionCoef) then
										FrictionDefault = math.abs(math.ceil(tonumber(T.frictionCoef) * Max - 0.5) / Max)
									end

									T.frictionCoef = "$"..part.."_FrictionCoef"
									frictionCoefFound = true
								end
								if T.slidingFrictionCoef then
									if tonumber(T.slidingFrictionCoef) then
										FrictionDefault = math.abs(math.ceil(tonumber(T.slidingFrictionCoef) * Max - 0.5) / Max)
									end

									T.slidingFrictionCoef = "$"..part.."_SlidingFrictionCoef"
									slidingFrictionCoefFound = true
								end
							end

							if FrictionDefault > Max then FrictionDefault = Max end
							if SlidingFrictionDefault > Max then SlidingFrictionDefault = Max end
							if FrictionDefault < Min then FrictionDefault = Min end
							if SlidingFrictionDefault < Min then SlidingFrictionDefault = Min end

							if not data.variables then
								data.variables = {{"name", "type", "unit", "category", "default", "min", "max", "title", "description"}}
							end

							data.variables[#data.variables + 1] = {"$"..part.."_FrictionCoef", "range", "Friction", "Wheels", FrictionDefault, Min, Max, part.." Friction", "Friction Coef", {stepDis = Min}}
							data.variables[#data.variables + 1] = {"$"..part.."_SlidingFrictionCoef", "range", "Sliding Friction", "Wheels", SlidingFrictionDefault, Min, Max, part.." Sliding Friction", "Sliding Friction Coef", {stepDis = Min}}

							if not frictionCoefFound then
								data[pressureOrHub][#data[pressureOrHub] + 1] = {frictionCoef = "$"..part.."_FrictionCoef"}
							end

							if not slidingFrictionCoefFound then
								data[pressureOrHub][#data[pressureOrHub] + 1] = {slidingFrictionCoef = "$"..part.."_SlidingFrictionCoef"}
							end

							local arr = {}
							arr[part..prefix] = data
							jsonWriteFile(jbeamPath:sub(0,-7)..part..prefix..".jbeam", arr, true)

							break
						end
					end
				end
			end
		end
		::continue::
	end
end

local function onExtensionLoaded()
	local currentGameVersion = tonumber(beamng_versiond:sub(3,6))
	local path = {}
	path.Made_On_Version = "temp/Variable_Grip_Tires_On_Lua/Made_On_Version.json"
	path.Delete_all_created = "temp/Variable_Grip_Tires_On_Lua/Delete_all_created.json"
	path.Everything_remotely = "temp/Variable_Grip_Tires_On_Lua/Everything_remotely.json"

	local readfile = {}
	readfile.Made_On_Version = jsonReadFile(path.Made_On_Version)
	readfile.Delete_all_created = jsonReadFile(path.Delete_all_created)
	readfile.Everything_remotely = jsonReadFile(path.Everything_remotely)

	if readfile.Everything_remotely and (readfile.Delete_all_created and readfile.Delete_all_created["Delete_all_created?"]) then
		return
	end

	if readfile.Everything_remotely and (not readfile.Delete_all_created or not readfile.Delete_all_created["Delete_all_created?"]) then
		os.remove(path.Everything_remotely)
		readfile.Made_On_Version = nil
	end

	if readfile.Made_On_Version and readfile.Made_On_Version["GameVersion"] == currentGameVersion and (readfile.Delete_all_created and not readfile.Delete_all_created["Delete_all_created?"]) then
		return
	else
		if not readfile.Delete_all_created then
			createFile(path.Delete_all_created, "Delete_all_created?", false)
		end

		if readfile.Delete_all_created and readfile.Delete_all_created["Delete_all_created?"] then
			create_or_remove("remove")
			createFile(path.Everything_remotely, "Done", true)
		end

		if (not readfile.Made_On_Version or readfile.Made_On_Version["GameVersion"] ~= currentGameVersion) and (not readfile.Delete_all_created or not readfile.Delete_all_created["Delete_all_created?"]) then
			createFile(path.Made_On_Version, "GameVersion", currentGameVersion)
			create_or_remove("create")
		end
	end
end

M.onExtensionLoaded = onExtensionLoaded
return M